package org.jvnet.annox.util;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

public class ElementUtils {

	private ElementUtils() {
	}

	public static String getValue(final Element annotationElement,
			final String name) {
		String value = null;

		final String attribute = annotationElement.getAttribute(name);
		if (!StringUtils.isEmpty(attribute)) {
			value = attribute;
		}

		final NodeList elements = annotationElement.getChildNodes();
		for (int index = 0; index < elements.getLength(); index++) {
			final Node node = elements.item(index);
			if (node.getNodeType() == Node.ELEMENT_NODE
					&& name.equals(node.getLocalName())) {
				final Element element = (Element) node;
				value = element.getTextContent();
			}
		}
		return value;
	}

	public static Element getElement(final Element annotationElement,
			final String name) {
		Element value = null;
		final NodeList elements = annotationElement.getChildNodes();
		for (int index = 0; index < elements.getLength(); index++) {
			final Node node = elements.item(index);
			if (node.getNodeType() == Node.ELEMENT_NODE
					&& name.equals(node.getLocalName())) {
				final Element element = (Element) node;
				final NodeList subelements = element.getChildNodes();
				for (int jndex = 0; jndex < subelements.getLength(); jndex++) {
					final Node subnode = subelements.item(jndex);
					if (subnode.getNodeType() == Node.ELEMENT_NODE) {
						value = (Element) subnode;
					}
				}
			}
		}
		return value;
	}

	public static String[] getValues(final Element annotationElement,
			final String name) {
		final List<String> values = new ArrayList<String>();
		final String attribute = annotationElement.getAttribute(name);
		if (!StringUtils.isEmpty(attribute)) {
			final String[] entries = StringUtils.split(attribute.trim(), ' ');
			values.addAll(Arrays.asList(entries));
		}

		final NodeList elements = annotationElement.getChildNodes();
		for (int index = 0; index < elements.getLength(); index++) {
			final Node node = elements.item(index);
			if (node.getNodeType() == Node.ELEMENT_NODE
					&& name.equals(node.getLocalName())) {
				final Element element = (Element) node;
				final String entry = element.getTextContent();
				values.add(entry);
			}
		}
		return values.isEmpty() ? new String[0] : values
				.toArray(new String[values.size()]);
	}

	public static Element[] getElements(final Element annotationElement,
			final String name) {
		final List<Element> values = new ArrayList<Element>();
		final NodeList elements = annotationElement.getChildNodes();
		for (int index = 0; index < elements.getLength(); index++) {
			final Node node = elements.item(index);
			if (node.getNodeType() == Node.ELEMENT_NODE
					&& name.equals(node.getLocalName())) {
				final Element element = (Element) node;
				final NodeList subelements = element.getChildNodes();
				for (int jndex = 0; jndex < subelements.getLength(); jndex++) {
					final Node subnode = subelements.item(jndex);
					if (subnode.getNodeType() == Node.ELEMENT_NODE) {
						values.add((Element) subnode);
					}
				}
			}
		}
		return values.isEmpty() ? new Element[0] : values
				.toArray(new Element[values.size()]);
	}
}
